@@ -1,6 +1,5 @@
 package Chef::Knife::Cmd::Vault;
 use Moo;
-use JSON::MaybeXS;
 
 has knife => (is => 'ro', required => 1, handles => [qw/handle_options run/]);
 
@@ -31,10 +30,4 @@ sub show {
     $self->run(@cmd);
 }
 
-sub item {
-    my ($self, $vault, $item, %options) = @_;
-    my $json = $self->show($vault, $item, format => 'json', %options);
-    return JSON->new->utf8->decode($json);
-}
-
 1;
